.. Charmcraft documentation root file

Charmcraft
==========

Charmcraft is part of the `Juju Charm SDK <https://juju.is/docs/sdk>`_.
Most of Charmcraft's documentation is available there.

.. toctree::
   :maxdepth: 1
   :hidden:

   reference/index
   explanation/index

.. grid:: 1 1 2 2
   :reverse:

   .. grid-item-card:: :ref:`Reference <reference>`

      **Technical information** about Charmcraft

   .. grid-item-card:: :ref:`Explanation <explanation>`

      **Discussion and clarification** of key topics

Project and community
=====================

Charmcraft is a member of the Canonical family. It's an open source project
that warmly welcomes community projects, contributions, suggestions, fixes
and constructive feedback.

* `Ubuntu Code of Conduct <https://ubuntu.com/community/code-of-conduct>`_.
* `Canonical contributor licenses agreement
  <https://ubuntu.com/legal/contributors>`_.

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
